summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--bfd/ChangeLog4
-rw-r--r--bfd/elfcore.h4
2 files changed, 7 insertions, 1 deletions
diff --git a/bfd/ChangeLog b/bfd/ChangeLog
index ea2af66ac3..169118ee63 100644
--- a/bfd/ChangeLog
+++ b/bfd/ChangeLog
@@ -1,3 +1,7 @@
+2002-01-28 Jason Thorpe <thorpej@wasabisystems.com>
+
+ * elfcore.h (elf_core_file_p): Improve comment for last change.
+
2002-01-27 Daniel Jacobowitz <drow@mvista.com>
* configure: Regenerated.
diff --git a/bfd/elfcore.h b/bfd/elfcore.h
index 5c818120a0..c206af5f6c 100644
--- a/bfd/elfcore.h
+++ b/bfd/elfcore.h
@@ -220,7 +220,9 @@ elf_core_file_p (abfd)
elf_swap_phdr_in (abfd, &x_phdr, i_phdrp + phindex);
}
- /* Set the machine architecture. */
+ /* Set the machine architecture. Do this before processing the
+ program headers since we need to know the architecture type
+ when processing the notes of some systems' core files. */
if (! bfd_default_set_arch_mach (abfd, ebd->arch, 0))
{
/* It's OK if this fails for the generic target. */